The BinaryOptionImpliedVolatility function solves for the
(unobservable) implied volatility, given an option price as well as
the other required parameters to value an option.
# S3 method for default
BinaryOptionImpliedVolatility(type, value, underlying,
strike, dividendYield, riskFreeRate, maturity, volatility,
cashPayoff=1, dayCounter=0)
The BinaryOptionImpliedVolatility function returns an numeric
variable with volatility implied by the given market prices.
A string with one of the values call, put or
straddle
Value of the option (used only for ImpliedVolatility calculation)
Current price of the underlying stock
Strike price of the option
Continuous dividend yield (as a fraction) of the stock
Risk-free rate
Time to maturity in either fractional years or as a ‘Date’ object specifying the expiry date)
Initial guess for the volatility of the underlying stock
Binary payout if options is exercised, default is 1
Integer denoting the selected QuantLib day counter convention, default value is 0 for ‘Actual360’
Dirk Eddelbuettel edd@debian.org for the R interface;
the QuantLib Group for QuantLib
The Finite Differences method is used to value the Binary Option. Implied volatilities are then calculated numerically.
Please see any decent Finance textbook for background reading, and the
QuantLib documentation for details on the QuantLib
implementation.
https://www.quantlib.org/ for details on QuantLib.
EuropeanOption,AmericanOption,BinaryOption
BinaryOptionImpliedVolatility("call", value=4.50, strike=100, 100, 0.02, 0.03, 0.5, 0.4, 10)
Run the code above in your browser using DataLab