Learn R Programming

RQuantLib (version 0.4.27)

Option: Base class for option price evalution

Description

This class forms the basis from which the more specific classes are derived.

Usage

# S3 method for Option
print(x, digits=4, ...)
# S3 method for Option
plot(x, ...)
# S3 method for Option
summary(object, digits=4, ...)

Value

None, but side effects of displaying content.

Arguments

x

Any option object derived from this base class

object

Any option object derived from this base class

digits

Number of digits of precision shown

...

Further arguments

Author

Dirk Eddelbuettel [email protected] for the R interface; the QuantLib Group for QuantLib

Details

Please see any decent Finance textbook for background reading, and the QuantLib documentation for details on the QuantLib implementation.

References

https://www.quantlib.org/ for details on QuantLib.

See Also

AmericanOption,EuropeanOption, BinaryOption

Examples

Run this code
EO<-EuropeanOption("call", strike=100, volatility=0.4, 100, 0.01, 0.03, 0.5)
print(EO)
summary(EO)

Run the code above in your browser using DataLab